package com.djhk.uav.equ.mapper;




import com.djhk.uav.equ.domain.EquModelParam;
import com.djhk.uav.equ.domain.EquParamDefine;
import com.djhk.uav.equ.domain.EquType;

import java.util.List;

/**
 * 设备类别Mapper接口
 * 
 * @author huangqingguo
 * @date 2023-06-02
 */
public interface EquTypeMapper 
{
    /**
     * 查询设备类别
     * 
     * @param typeId 设备类别主键
     * @return 设备类别
     */
    public EquType selectEquTypeByTypeId(String typeId);

    /**
     * 查询设备类别列表
     * 
     * @param equType 设备类别
     * @return 设备类别集合
     */
    public List<EquType> selectEquTypeList(EquType equType);

    /**
     * 新增设备类别
     * 
     * @param equType 设备类别
     * @return 结果
     */
    public int insertEquType(EquType equType);

    /**
     * 修改设备类别
     * 
     * @param equType 设备类别
     * @return 结果
     */
    public int updateEquType(EquType equType);

    /**
     * 删除设备类别
     * 
     * @param typeId 设备类别主键
     * @return 结果
     */
    public int deleteEquTypeByTypeId(String typeId);

    /**
     * 批量删除设备类别
     * 
     * @param typeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEquTypeByTypeIds(String[] typeIds);


    public List<EquType> selectEquType();

    List<EquParamDefine> getEqumodelDefine(Long typeId);

    List<EquModelParam> getEqumodelParam(Long modelId);

    EquType selectEquTypeByTypeName(String typeName);
}
