package com.djhk.uav.equ.controller;


import com.djhk.common.core.controller.BaseController;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 设备类别Controller
 * 
 * @author huangqingguo
 * @date 2023-06-02
 */
@RestController
@RequestMapping("/equType")
public class EquTypeController extends BaseController
{
//    @Autowired
//    private IEquTypeService equTypeService;
//
//    /**
//     * 查询设备类别列表
//     */
//    @RequiresPermissions("system:equType:list")
//    @GetMapping("/list")
//    public TableDataInfo list(EquType equType)
//    {
//        startPage();
//        List<EquType> list = equTypeService.selectEquTypeList(equType);
//        return getDataTable(list);
//    }
//
//    /**
//     * 导出设备类别列表
//     */
//    @RequiresPermissions("system:equType:export")
//    @Log(title = "设备类别", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, EquType equType)
//    {
//        List<EquType> list = equTypeService.selectEquTypeList(equType);
//        ExcelUtil<EquType> util = new ExcelUtil<EquType>(EquType.class);
//        util.exportExcel(response, list, "设备类别数据");
//    }
//
//    /**
//     * 获取设备类别详细信息
//     */
//    @RequiresPermissions("system:equType:query")
//    @GetMapping(value = "/{typeId}")
//    public R<EquType> getInfo(@PathVariable("typeId") String typeId)
//    {
//        EquType equType = equTypeService.selectEquTypeByTypeId(typeId);
//        return R.ok(equType);
//    }
//
//    /**
//     * 新增设备类别
//     */
//    @RequiresPermissions("system:equType:add")
//    @Log(title = "设备类别", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody EquType equType)
//    {
//        return toAjax(equTypeService.insertEquType(equType));
//    }
//
//    /**
//     * 修改设备类别
//     */
//    @RequiresPermissions("system:equType:edit")
//    @Log(title = "设备类别", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody EquType equType)
//    {
//        return toAjax(equTypeService.updateEquType(equType));
//    }
//
//    /**
//     * 删除设备类别
//     */
//    @RequiresPermissions("system:equType:remove")
//    @Log(title = "设备类别", businessType = BusinessType.DELETE)
//	@DeleteMapping("/{typeIds}")
//    public AjaxResult remove(@PathVariable String[] typeIds)
//    {
//        return toAjax(equTypeService.deleteEquTypeByTypeIds(typeIds));
//    }
}
